<?php
    $directoryURI = $_SERVER['REQUEST_URI'];
    $path = parse_url($directoryURI, PHP_URL_PATH);
    $components = explode('/', $path);
    $first_part = $components[2];

?>

<div id="navigation">
    <ul class="nav" id="side-menu">
        <li class=<?php if ($first_part=="information.php") {echo "active"; } else  {echo "noactive";}?>>
            <a href="information.php"> <img src="icons/Information.png" alt="Information" height="30" width="30"><span class="nav-label"> Information</span></a>
        </li>
        <li class=<?php if ($first_part=="logging.php") {echo "active"; } else  {echo "noactive";}?>>
            <a href="logging.php"> <img src="icons/Logging.png" alt="Logging" height="30" width="30"><span class="nav-label"> Logging</span> </a>
        </li>
        <li class=<?php if ($first_part=="app_mgmt.php") {echo "active"; } else  {echo "noactive";}?>>
            <a href="app_mgmt.php"> <img src="icons/AppMgt.png" alt="App. Managment" height="30" width="30"><span class="nav-label"> App. Mgmt</span> </a>
        </li>
        <li class=<?php if ($first_part=="advanced.php") {echo "active"; } else  {echo "noactive";}?>>
            <a href="advanced.php"> <img src="icons/Advanced.png" alt="Advanced" height="30" width="30"><span class="nav-label"> Advanced</span> </a>
        </li>
    </ul>
</div>
