<div class="color-line">
</div>
<div id="logo" class="light-version">
    <span>
        Web-Engine
    </span>
</div>
<nav role="navigation">
    <div class="header-link hide-menu"><i class="fa fa-bars"></i></div>
    <div class="small-logo">
        <span class="text-primary">Web Engine</span>
    </div>

    <!-- <div class="mobile-menu">
        <button type="button" class="navbar-toggle mobile-menu-toggle" data-toggle="collapse" data-target="#mobile-collapse">
            <i class="fa fa-chevron-down"></i>
        </button>
        <div class="collapse mobile-navbar" id="mobile-collapse">
            <ul class="nav navbar-nav">
                <li>
                    <a class="" href="#">Link</a>
                </li>
                <li>
                    <a class="" href="#">Link</a>
                </li>
            </ul>
        </div>
    </div> -->

</nav>
