#
# Following section defines an equipment type
#
.ID
#
# Equipment=<equipment type name>,<base name>,<interface>
#
#   <equipment type name> is purely informational
#   <base name> supplies the base object name and those of the channels
#   <interface> = rs485/tcpip/both
#
Equipment=eDrive34,E34,rs485
#
# Following section defines the channels provided by the equipment
#
.Channels
#
# <channel name>=<type>,<unittype>,<unitcode>,<min>,<max>
#
#   <type> = 0:3, CHANNEL_TYPE_xxxx
#   <unittype> = UNITTYPE_IS_xxx
#   <unitcode> = UNITCODE_IS_xxx
#   <min> = minimum acceptable value, natural units
#   <max> = maximum acceptable value, natural units
#
# eDrive34: Cmd (setpoint) is in mA by default
Cmd=2
# eDrive34: Position (feedback) is by default in %
FB=0,4,0,0,100
LowAlarm=1
HighAlarm=1
#
# Following section(s) defines Modbus read request(s):
#
# registers=<function code>,<register address>,<read count>
#
#   <function code> = Modbus function code to use
#   <register address> = address of 1st register to read
#   <read count> = number of 16-bit registers to read
#
.ReadRequest 1
registers=4,23,5
#
# <channel name>=<offset>,<type>,<format>,<state>{[,<scale>]}|{,<min>,<max>}
#
#   <offset> = register offset in reply
#   <type> = int16/int32/float
#   <format> = moto/intel (applies only to int32 and float)
#   <state> = cooked/raw
#
#   if state is "cooked", there is an optional scaling factor <scale> ie vbatt is
#       provided as mV * 10, so there is a scaling factor of 0.01 to bring that
#       to the volts we are expecting. If not supplied, <scale> is 1
#
#   if state is "raw" then min/max for the raw data values must be supplied so
#       that the D22 can calculate gain+offset to get from the raw value to the
#       physical min/max defined for the channel
#
Cmd=0,int16,moto,raw,40,200
FB=2,int16,moto,raw,40,200
LowAlarm=3,int16,moto,cooked
HighAlarm=4,int16,moto,cooked
#
# Following section(s) define write request(s). Format is as above
#
.WriteRequest 1
registers=16,23,2
Cmd=0,int16,moto,raw,40,200
