#!/bin/sh
  case "${ACTION}" in
    add|"")
	sleep 1
	hciconfig ${MDEV} up piscan name 'D12'
	pand --search -r PANU -d PANU -p 5 -u '/etc/bluetooth/pan/dev_up' -o '/etc/bluetooth/pan/dev_down' -A -E -S
      ;;
    remove)
      ;;
  esac
